==> ejc-zjkjcost-impl-3.0.0-20221103.065130-73-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeAssessEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节点考核-项目节点奖分析考核
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_node_assess")
public class NodeAssessEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="exec_book")
    private String execBook; // 根据目标责任书约定执行
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同款价
    @TableField(value="assess_basis_content")
    private String assessBasisContent;

    @TableField(value="output_cost")
    private String outputCost;  //产值与成本情况
    @TableField(value="financial_fund_management")
    private String financialFundManagement; //财务资金管理情况
    @TableField(value="pmanager_signature")
    private String pmanagerSignature;   //项目经理签字(审批)
    @TableField(value="cmanager_signature")
    private String cmanagerSignature;   //所属单位商务部经理签字(审批)
    @TableField(value="caiwukuaiji_sign")
    private String caiwukuaijiSign; //所属单位财务资金部、总会计师签字(审批)
    @TableField(value="lingdao_qinazi")
    private String lingdaoQinazi;   //所属单位分管领导(审批)
    @TableField(value="tmanager_signature")
    private String tmanagerSignature;   //所属单位总经理(审批)

    public String getAssessBasisContent() {
        return assessBasisContent;
    }

    public void setAssessBasisContent(String assessBasisContent) {
        this.assessBasisContent = assessBasisContent;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getExecBook() {
        return execBook;
    }

    public void setExecBook(String execBook) {
        this.execBook = execBook;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public String getOutputCost() {
        return outputCost;
    }

    public void setOutputCost(String outputCost) {
        this.outputCost = outputCost;
    }

    public String getFinancialFundManagement() {
        return financialFundManagement;
    }

    public void setFinancialFundManagement(String financialFundManagement) {
        this.financialFundManagement = financialFundManagement;
    }

    public String getPmanagerSignature() {
        return pmanagerSignature;
    }

    public void setPmanagerSignature(String pmanagerSignature) {
        this.pmanagerSignature = pmanagerSignature;
    }

    public String getCmanagerSignature() {
        return cmanagerSignature;
    }

    public void setCmanagerSignature(String cmanagerSignature) {
        this.cmanagerSignature = cmanagerSignature;
    }

    public String getCaiwukuaijiSign() {
        return caiwukuaijiSign;
    }

    public void setCaiwukuaijiSign(String caiwukuaijiSign) {
        this.caiwukuaijiSign = caiwukuaijiSign;
    }

    public String getLingdaoQinazi() {
        return lingdaoQinazi;
    }

    public void setLingdaoQinazi(String lingdaoQinazi) {
        this.lingdaoQinazi = lingdaoQinazi;
    }

    public String getTmanagerSignature() {
        return tmanagerSignature;
    }

    public void setTmanagerSignature(String tmanagerSignature) {
        this.tmanagerSignature = tmanagerSignature;
    }
}

==> ejc-zjkjcost-impl-3.0.0-20230418.113208-133-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeAssessEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节点考核-项目节点奖分析考核
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_node_assess")
public class NodeAssessEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="exec_book")
    private String execBook; // 根据目标责任书约定执行
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同款价
    @TableField(value="assess_basis_content")
    private String assessBasisContent;

    @TableField(value="output_cost")
    private String outputCost;  //产值与成本情况
    @TableField(value="financial_fund_management")
    private String financialFundManagement; //财务资金管理情况
    @TableField(value="pmanager_signature")
    private String pmanagerSignature;   //项目经理签字(审批)
    @TableField(value="cmanager_signature")
    private String cmanagerSignature;   //所属单位商务部经理签字(审批)
    @TableField(value="caiwukuaiji_sign")
    private String caiwukuaijiSign; //所属单位财务资金部、总会计师签字(审批)
    @TableField(value="lingdao_qinazi")
    private String lingdaoQinazi;   //所属单位分管领导(审批)
    @TableField(value="tmanager_signature")
    private String tmanagerSignature;   //所属单位总经理(审批)
    @TableField(value="material_manage")
    private String materialManage;   //所属单位物资设备管理职能部门经理签字

    public String getMaterialManage() {
        return materialManage;
    }

    public void setMaterialManage(String materialManage) {
        this.materialManage = materialManage;
    }

    public String getAssessBasisContent() {
        return assessBasisContent;
    }

    public void setAssessBasisContent(String assessBasisContent) {
        this.assessBasisContent = assessBasisContent;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getExecBook() {
        return execBook;
    }

    public void setExecBook(String execBook) {
        this.execBook = execBook;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }

    public String getOutputCost() {
        return outputCost;
    }

    public void setOutputCost(String outputCost) {
        this.outputCost = outputCost;
    }

    public String getFinancialFundManagement() {
        return financialFundManagement;
    }

    public void setFinancialFundManagement(String financialFundManagement) {
        this.financialFundManagement = financialFundManagement;
    }

    public String getPmanagerSignature() {
        return pmanagerSignature;
    }

    public void setPmanagerSignature(String pmanagerSignature) {
        this.pmanagerSignature = pmanagerSignature;
    }

    public String getCmanagerSignature() {
        return cmanagerSignature;
    }

    public void setCmanagerSignature(String cmanagerSignature) {
        this.cmanagerSignature = cmanagerSignature;
    }

    public String getCaiwukuaijiSign() {
        return caiwukuaijiSign;
    }

    public void setCaiwukuaijiSign(String caiwukuaijiSign) {
        this.caiwukuaijiSign = caiwukuaijiSign;
    }

    public String getLingdaoQinazi() {
        return lingdaoQinazi;
    }

    public void setLingdaoQinazi(String lingdaoQinazi) {
        this.lingdaoQinazi = lingdaoQinazi;
    }

    public String getTmanagerSignature() {
        return tmanagerSignature;
    }

    public void setTmanagerSignature(String tmanagerSignature) {
        this.tmanagerSignature = tmanagerSignature;
    }
}
